"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const readdir_enhanced_1 = require("readdir-enhanced");
const create_file_1 = require("./create-file");
/**
 * Reads a single file, if it meets the filter criteria.
 */
async function readFile(path, config, run) {
    let file = create_file_1.createFile(path.filename, path.absolutePath, path.stats);
    if (config.filter(file, run)) {
        file.contents = await config.fs.promises.readFile(path.absolutePath);
        return file;
    }
}
exports.readFile = readFile;
/**
 * Reads files from the filesystem and yields the ones that match the configuration critiera.
 */
function readDir(path, config, run) {
    let files = find(path, config, run);
    return {
        [Symbol.asyncIterator]() {
            return { next: readNextFile };
        }
    };
    async function readNextFile() {
        let result = await files.next();
        if (result.done) {
            return { done: true, value: undefined };
        }
        else {
            let stats = result.value;
            if (stats.isFile()) {
                let absolutePath = path_1.join(path.dir, stats.path);
                let file = create_file_1.createFile(stats.path, absolutePath, stats);
                file.contents = await config.fs.promises.readFile(absolutePath);
                return { value: file };
            }
            else {
                return readNextFile();
            }
        }
    }
}
exports.readDir = readDir;
/**
 * Finds all files in the directory that match the filter criteria
 */
function find(path, config, run) {
    let filter;
    if (typeof config.filterCriteria === "function") {
        let codeEngineFileFilter = config.filterCriteria;
        filter = (stats) => {
            let absolutePath = path_1.join(path.dir, stats.path);
            let file = create_file_1.createFile(stats.path, absolutePath, stats);
            return codeEngineFileFilter(file, run);
        };
    }
    else {
        filter = config.filterCriteria;
    }
    return readdir_enhanced_1.readdirIterator(path.dir, {
        stats: true,
        deep: config.depth,
        fs: config.fs,
        filter,
    });
}
//# sourceMappingURL=read.js.map